package org.dromara.ems.record.service;

import org.dromara.ems.record.domain.EmsRecordAlarmRule;

import java.util.List;

/**
 * 异常告警规则Service接口
 * 
 * @author Yinq
 * @date 2024-05-15
 */
public interface IEmsRecordAlarmRuleService 
{
    /**
     * 查询异常告警规则
     * 
     * @param objId 异常告警规则主键
     * @return 异常告警规则
     */
    public EmsRecordAlarmRule selectEmsRecordAlarmRuleByObjId(Long objId);

    /**
     * 查询异常告警规则列表
     * 
     * @param emsRecordAlarmRule 异常告警规则
     * @return 异常告警规则集合
     */
    public List<EmsRecordAlarmRule> selectEmsRecordAlarmRuleList(EmsRecordAlarmRule emsRecordAlarmRule);

    /**
     * 新增异常告警规则
     * 
     * @param emsRecordAlarmRule 异常告警规则
     * @return 结果
     */
    public int insertEmsRecordAlarmRule(EmsRecordAlarmRule emsRecordAlarmRule);

    /**
     * 修改异常告警规则
     * 
     * @param emsRecordAlarmRule 异常告警规则
     * @return 结果
     */
    public int updateEmsRecordAlarmRule(EmsRecordAlarmRule emsRecordAlarmRule);

    /**
     * 批量删除异常告警规则
     * 
     * @param objIds 需要删除的异常告警规则主键集合
     * @return 结果
     */
    public int deleteEmsRecordAlarmRuleByObjIds(Long[] objIds);

    /**
     * 删除异常告警规则信息
     * 
     * @param objId 异常告警规则主键
     * @return 结果
     */
    public int deleteEmsRecordAlarmRuleByObjId(Long objId);

    /**
     * 查询异常告警规则总数
     *
     * @return 告警规则总数
     */
    public int getEmsRecordAlarmRuleTotalCount();
}
